Started to rescind the name "skin", replacing it with "tool".  Did this in all
the places that normal users will see:

  - command line: --tool=foo (although --skin=foo still works)
  - docs: removed all traces (included renaming coregrind_skins.html to
    coregrind_tools.html)
  - in the usage messages
  - in error messages

Also did in in some places that I judged were unlikely to cause clashes with
existing workspaces:

  - in the header comments of many files (eg. "This file is part of Memcheck, a
    Valgrind tool for...")
  - in the regtests script
  - in the .supp files
  - in AUTHORS
  - in README_MISSING_SYSCALL_OR_IOCTL

Also update the AUTHORS file to mention Jeremy.


git-svn-id: svn://svn.valgrind.org/valgrind/trunk@2027 a5019735-40e9-0310-863c-91ae7b9d1cf9
diff --git a/lackey/lk_main.c b/lackey/lk_main.c
index bb3aa44..a68841b 100644
--- a/lackey/lk_main.c
+++ b/lackey/lk_main.c
@@ -1,11 +1,11 @@
 
 /*--------------------------------------------------------------------*/
 /*--- Simple skin for counting UInstrs, using a C helper.          ---*/
 /*---                                                    lk_main.c ---*/
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of Lackey, an example Valgrind skin that does
+   This file is part of Lackey, an example Valgrind tool that does
    some simple program measurement.
 
    Copyright (C) 2002-2003 Nicholas Nethercote
@@ -78,7 +78,7 @@
 {
    VG_(details_name)            ("Lackey");
    VG_(details_version)         (NULL);
-   VG_(details_description)     ("an example Valgrind skin");
+   VG_(details_description)     ("an example Valgrind tool");
    VG_(details_copyright_author)(
       "Copyright (C) 2002-2003, and GNU GPL'd, by Nicholas Nethercote.");
    VG_(details_bug_reports_to)  ("njn25@cam.ac.uk");
@@ -1,11 +1,11 @@
 
 /*--------------------------------------------------------------------*/
-/*--- Simple skin for counting UInstrs, using a C helper.          ---*/
+/*--- Simple tool for counting UInstrs, using a C helper.          ---*/
 /*---                                                    lk_main.c ---*/
 /*--------------------------------------------------------------------*/